==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/SecuritySettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.SecuritySettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Security Settings of the vault
 * @property immutabilitySettings Immutability Settings of a vault
 * @property softDeleteSettings Soft delete Settings of a vault
 */
public data class SecuritySettingsArgs(
    public val immutabilitySettings: Output<ImmutabilitySettingsArgs>? = null,
    public val softDeleteSettings: Output<SoftDeleteSettingsArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.SecuritySettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.SecuritySettingsArgs =
        com.pulumi.azurenative.recoveryservices.inputs.SecuritySettingsArgs.builder()
            .immutabilitySettings(
                immutabilitySettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .softDeleteSettings(
                softDeleteSettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [SecuritySettingsArgs].
 */
@PulumiTagMarker
public class SecuritySettingsArgsBuilder internal constructor() {
    private var immutabilitySettings: Output<ImmutabilitySettingsArgs>? = null

    private var softDeleteSettings: Output<SoftDeleteSettingsArgs>? = null

    /**
     * @param value Immutability Settings of a vault
     */
    @JvmName("cxccjywjkfefvkxe")
    public suspend fun immutabilitySettings(`value`: Output<ImmutabilitySettingsArgs>) {
        this.immutabilitySettings = value
    }

    /**
     * @param value Soft delete Settings of a vault
     */
    @JvmName("edtdyercytnfnjvc")
    public suspend fun softDeleteSettings(`value`: Output<SoftDeleteSettingsArgs>) {
        this.softDeleteSettings = value
    }

    /**
     * @param value Immutability Settings of a vault
     */
    @JvmName("filrtmxmqlodfpmy")
    public suspend fun immutabilitySettings(`value`: ImmutabilitySettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.immutabilitySettings = mapped
    }

    /**
     * @param argument Immutability Settings of a vault
     */
    @JvmName("labkqweavxphnjok")
    public suspend
    fun immutabilitySettings(argument: suspend ImmutabilitySettingsArgsBuilder.() -> Unit) {
        val toBeMapped = ImmutabilitySettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.immutabilitySettings = mapped
    }

    /**
     * @param value Soft delete Settings of a vault
     */
    @JvmName("hrtbwdhaxnyewpie")
    public suspend fun softDeleteSettings(`value`: SoftDeleteSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.softDeleteSettings = mapped
    }

    /**
     * @param argument Soft delete Settings of a vault
     */
    @JvmName("rianglbvpytosonn")
    public suspend
    fun softDeleteSettings(argument: suspend SoftDeleteSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = SoftDeleteSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.softDeleteSettings = mapped
    }

    internal fun build(): SecuritySettingsArgs = SecuritySettingsArgs(
        immutabilitySettings = immutabilitySettings,
        softDeleteSettings = softDeleteSettings,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/SecuritySettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.SecuritySettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Security Settings of the vault
 * @property immutabilitySettings Immutability Settings of a vault
 * @property softDeleteSettings Soft delete Settings of a vault
 */
public data class SecuritySettingsArgs(
    public val immutabilitySettings: Output<ImmutabilitySettingsArgs>? = null,
    public val softDeleteSettings: Output<SoftDeleteSettingsArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.SecuritySettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.SecuritySettingsArgs =
        com.pulumi.azurenative.recoveryservices.inputs.SecuritySettingsArgs.builder()
            .immutabilitySettings(
                immutabilitySettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .softDeleteSettings(
                softDeleteSettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [SecuritySettingsArgs].
 */
@PulumiTagMarker
public class SecuritySettingsArgsBuilder internal constructor() {
    private var immutabilitySettings: Output<ImmutabilitySettingsArgs>? = null

    private var softDeleteSettings: Output<SoftDeleteSettingsArgs>? = null

    /**
     * @param value Immutability Settings of a vault
     */
    @JvmName("fgpootdotpdqwlqf")
    public suspend fun immutabilitySettings(`value`: Output<ImmutabilitySettingsArgs>) {
        this.immutabilitySettings = value
    }

    /**
     * @param value Soft delete Settings of a vault
     */
    @JvmName("pqsddcteonxvubhx")
    public suspend fun softDeleteSettings(`value`: Output<SoftDeleteSettingsArgs>) {
        this.softDeleteSettings = value
    }

    /**
     * @param value Immutability Settings of a vault
     */
    @JvmName("auewdcbempjursuh")
    public suspend fun immutabilitySettings(`value`: ImmutabilitySettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.immutabilitySettings = mapped
    }

    /**
     * @param argument Immutability Settings of a vault
     */
    @JvmName("luvqdfhnmwwlvajh")
    public suspend
    fun immutabilitySettings(argument: suspend ImmutabilitySettingsArgsBuilder.() -> Unit) {
        val toBeMapped = ImmutabilitySettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.immutabilitySettings = mapped
    }

    /**
     * @param value Soft delete Settings of a vault
     */
    @JvmName("rklntwglpckromig")
    public suspend fun softDeleteSettings(`value`: SoftDeleteSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.softDeleteSettings = mapped
    }

    /**
     * @param argument Soft delete Settings of a vault
     */
    @JvmName("lkdwqbmpesrfhhpx")
    public suspend
    fun softDeleteSettings(argument: suspend SoftDeleteSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = SoftDeleteSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.softDeleteSettings = mapped
    }

    internal fun build(): SecuritySettingsArgs = SecuritySettingsArgs(
        immutabilitySettings = immutabilitySettings,
        softDeleteSettings = softDeleteSettings,
    )
}
